@@ -149,6 +149,9 @@ def pipeline():
         print 'set sirius.param properly'
         sys.exit()
 
+    # mfile is removed
+    mfkeep = 0
+
     os.mkdir('ffiles')
 
     #
@@ -356,13 +359,22 @@ def pipeline():
 
             print 'combining'
             imgrecom.recomb(band, urms, lstarnum, reject)
+            print 'done'
+            print ''
+
+            os.remove(band+'imgrecom.list')
 
-            if not os.access('mfile', os.F_OK):
-                os.mkdir('mfile')
             for file in glob.glob('ap*.mag'):
                 os.remove(file)
-            for file in glob.glob('*.mag'):
-                shutil.move(file, 'mfile')
+
+            if mfkeep == 0:
+                for file in glob.glob('*.mag'):
+                    os.remove(file)
+            else:
+                if not os.access('mfile', os.F_OK):
+                    os.mkdir('mfile')
+                for file in glob.glob('*.mag'):
+                    shutil.move(file, 'mfile')
 
         iraf.chdir()
         os.remove(v[0])
